djangocms-bootstrap
===================

A collection of plugins for DjangoCMS to add various HTML elements from the CSS framework
“Twitter Bootstrap” to CMS placeholders. This allows the editor of a web page to manipulate the DOM,
without having to edit HTML templates.

Example
-------
![Example](https://raw.github.com/jrief/djangocms-bootstrap/master/docs/source/_static/bootstrap-column-editor.png)

Build status
------------
[![Build Status](https://travis-ci.org/jrief/djangocms-bootstrap.png?branch=master)](https://travis-ci.org/jrief/djangocms-bootstrap)

Features
--------
* Use the **Bootstrap** scaffolding technique.
* Use **Bootstrap** buttons styles for your links.
* Insert **Boostrap Carousel** elements into the DOM.
* Add thumbnails and images using highly customizable **Bootstraps** markup.
* Its very easy to integrate your own plugin, often with less than 10 lines of code.
* Can also be used for any other CSS framework.

Find detailed documentation on [ReadTheDocs](http://djangocms-bootstrap.readthedocs.org/en/latest/).

Please read http://getbootstrap.com/2.3.2/ for details about the *Bootstrap* CSS framework.

License
-------
Released under the terms of MIT License.

Copyright (C) 2013, Jacob Rief <jacob.rief@gmail.com>
